#
# spec file for package openqa-mon
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           openqa-mon
Version:        1.5.0
Release:        1.1
Summary:        CLI monitoring utility for openQA
License:        GPL-3.0-or-later
URL:            https://github.com/os-autoinst/openqa-mon/
Source:         openqa-mon-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  golang-packaging
BuildRequires:  golang(API) >= 1.21
Recommends:     libnotify-tools
%{go_nostrip}

%description
openqa-mon is a CLI monitoring client for openqa written in plain go.

%prep
%autosetup -D -a 1

%build
make all GOARGS="-mod vendor -buildmode pie"

%install
# Manual install (for now)
install -Dm 755 openqa-mon %{buildroot}/%{_bindir}/openqa-mon
install -Dm 755 openqa-mq %{buildroot}/%{_bindir}/openqa-mq
install -Dm 755 openqa-revtui %{buildroot}/%{_bindir}/openqa-revtui
install -Dm 644 doc/openqa-mon.8 %{buildroot}/%{_mandir}/man8/openqa-mon.8

%files
%doc README.md
%{_bindir}/openqa-mon
%{_bindir}/openqa-mq
%{_bindir}/openqa-revtui
%{_mandir}/man8/openqa-mon.8%{?ext_man}

%changelog
* Wed May 14 2025 Felix Niederwanger <felix.niederwanger@suse.de>
- Update to version 1.5.0:
  * Prepare 1.5.0 release
  * Allow passing of overview links
  * Bump golang.org/x/crypto from 0.31.0 to 0.35.0
  * Add man pages for all tools
  * Update README
  * Unify RequestJobLimit setting
  * Fix panic when RequestJobLimit is not set
  * Minor refactoring
  * Remove unused functions
  * Remove year
* Tue Jan 14 2025 felix.niederwanger@suse.de
- Update to version 1.4.0:
  * Release version 1.4.0
  * Set correct groupid to match with description
  * Prepare 1.4.0 RC1 release
  * Refactoring
  * Introduce tabs
* Mon Nov 25 2024 felix.niederwanger@suse.de
- Update to version 1.3.1:
  * Prepeare maintenance release
  * Update cmd/openqa-mon/util.go
  * Update dependencies
  * Add SLEM6
  * Refactor util with generics and cleanup
  * Consider no arguments wrong usage
  * Update module dependencies
  * Update QE-C Maintenance template
  * Remove unneeded code
  * Move project to os-autoinst
  * ci: Run workflow on pull requests as well
  * Set version not go to 1.21  in workflows
  * Propagate err in checkReviewed
  * Set version to release
* Wed Aug 21 2024 felix.niederwanger@suse.de
- Update to version 1.3.0:
  * Fix header when resizing
* Wed Aug 21 2024 felix.niederwanger@suse.de
- Update to version 1.3.0-rc:
  * Prepare new release candidate
  * Improve pagination for openqa-mon
  * Add pagination on TUI
  * Limit number of jobs per http request
  * Refactor config.go
  * Update readme image link
  * Remove unnecessary functions
  * Refactor utility functions
* Tue Jul  9 2024 felix.niederwanger@suse.de
- Update to version 1.2.2:
  * Bump version to 1.2.2
  * Refactor VERSION
  * Update rabbitmq dependency
  * Update dependencies
  * Add SLE-Micro job groups
  * Avoid single LOC function, use strings.Repeat()
  * Add test rule to Makefile
  * Add test for remote URI
  * Make openqa-mon testable again
* Thu Apr  4 2024 felix.niederwanger@suse.de
- Update to version 1.2.1:
  * Bump version to 1.2.1
  * Update go dependencies
  * Add template for container jobs on O3
  * Quit if there are no jobs to display
  * Add filter for non-production runs
  * Update meta-file to recent changes
  * Add 15-SP6 WSL
  * Update SLEM to Container MU
  * Add 15-SP6
  * Remove wicked
* Mon Mar 18 2024 Felix Niederwanger <felix.niederwanger@suse.de>
- Add libnotify-tools as recommended package for notifications
- Disable obs_scm service
* Mon Mar 18 2024 felix.niederwanger@suse.de
- Update to version 1.2.0:
  * Remove the ALP config files
* Wed Dec 20 2023 felix.niederwanger@suse.de
- Update to version 1.2.0:
  * Bump version to 1.2.0
  * Add temporary status fields
  * Refactor style suggestions
  * Display reviewed jobs in summary as reviewed
  * Bump golang.org/x/crypto from 0.13.0 to 0.17.0
  * Rename jeos, wicked, wsl
  * Update QE-C configuration files
  * Bump actions/setup-go from 4 to 5
  * Separate SLEM for PC from SLEM
  * Update dependencies
  * Set lastest state of job groups to config
  * Bump actions/checkout from 2 to 4
* Fri Aug  4 2023 felix.niederwanger@suse.com
- Update to version 1.1.0:
  * Bump version to 1.1.0
  * Add failsafe to not open more than 10 links
  * Follow jobs
  * Update the SLEM review
  * Add ALP example config
  * Add reconnect handler for RabbitMQ
* Fri Aug  4 2023 Felix Niederwanger <felix.niederwanger@suse.com>
- Add changesgenerate to service file
* Fri Jul 28 2023 Felix Niederwanger <felix.niederwanger@suse.com>
- Update to version 1.1.0
  * [openqa-mon] Add reconnect handler for RabbitMQ (#115)
  * [openqa-revtui[ Add ability to open all visible URLs in browser (https://github.com//pull/113) by @asmorodskyi
  * [openqa-revtui] Refresh cloned jobs (#123)
  * [openqa-revtui] Don't open more than 10 links unless explicitly stated (#123)
  * Bump dependency versions
* Thu Mar 30 2023 Felix Niederwanger <felix.niederwanger@suse.com>
- Update to version 1.0.1
  * Upgrade to gopenqa 0.7.1 and align version number
* Thu Mar 30 2023 Felix Niederwanger <felix.niederwanger@suse.com>
- Update to version 1.0.0
  * Switch to single request for multiple jobs (openqa-mon and openqa-revtui)
  * Improve review templates
  * Consider the parallel_failed status (openqa-revtui)
  * Add progress when loading jobs (openqa-revtui)
  * Introduce colors in status field (openqa-revtui)
  * Rate limit continuous refresh on OSD and O3
  * Show job progress in Refresh line (openqa-revtui)
* Sat Mar 18 2023 Jeff Kowalczyk <jkowalczyk@suse.com>
- _service obs_scm revision change branch to main from master which
  no longer exists.
* Thu Mar 16 2023 Felix Niederwanger <felix.niederwanger@suse.com>
- Update to version 0.27
  * Fix incomplete jobs not considered with --exit
  * Refactoring of the revtui screen
  * Introduce the --input parameter in openqa-mon
  * Many small bugfixes
* Fri Jan 13 2023 Felix Niederwanger <felix.niederwanger@suse.com>
- Update to version 0.26
  - Many revtui improvements
  - Add experimental support for RabbitMQ in openqa-mon
  - openqa-mq supports connecting to arbitrary servers
  - Many small bugfixes
* Fri Dec  3 2021 Felix Niederwanger <felix.niederwanger@suse.com>
- Update to upstream version 0.25
  - New interaction options for openqa-mon
  - openqa-revtui received the "reviewed" keyword
* Fri Aug 13 2021 Felix Niederwanger <felix.niederwanger@suse.com>
- Add useragent
* Fri Jun 18 2021 Felix Niederwanger <felix.niederwanger@suse.com>
- Update go build version requirements
* Fri Jun  4 2021 Felix Niederwanger <felix.niederwanger@suse.com>
- Fix incomplete display when job has more than 10 clones
* Wed May 12 2021 Felix Niederwanger <felix.niederwanger@suse.com>
- Add --version to programs
- Ignore skipped and cancelled jobs from notifications
* Thu Apr 29 2021 Felix Niederwanger <felix.niederwanger@suse.com>
- openqa-revtui: Follow jobs
- openqa-revtui: Mark failed jobs with bug refs as reviewed
* Fri Apr 16 2021 Felix Niederwanger <felix.niederwanger@suse.com>
- Tidy
* Fri Apr 16 2021 Felix Niederwanger <felix.niederwanger@suse.com>
- Add 0.20
* Fri Apr 16 2021 Felix Niederwanger <felix.niederwanger@suse.com>
- Hotfix: Continuous program argument
* Fri Apr 16 2021 Felix Niederwanger <felix.niederwanger@suse.com>
- Update to version 0.2
* Tue Mar  9 2021 Felix Niederwanger <felix.niederwanger@suse.com>
- Remove unncessary go version
* Mon Mar  8 2021 Felix Niederwanger <felix.niederwanger@suse.com>
- Include openqa-mq and openqa-revtui
* Mon Mar  8 2021 Felix Niederwanger <felix.niederwanger@suse.com>
- Update to version 0.13
* Mon Mar  8 2021 Felix Niederwanger <felix.niederwanger@suse.com>
- Update to v0.12a
* Fri Feb 26 2021 Pavel Dostál <pdostal@suse.com>
- Add _service for the git and go forkflow
- Package version v0.12a
* Thu Dec 10 2020 Felix Niederwanger <felix.niederwanger@suse.com>
- Update to version 0.12
- Ignore url fragments
- Refactoring of the internal job ID process
* Wed Nov 11 2020 Felix Niederwanger <felix.niederwanger@suse.com>
- Update to version 0.11
* Fri Jul 17 2020 Martin Pluskal <mpluskal@suse.com>
- Initial changelog entry for version 0.1
